@@ -1498,6 +1498,29 @@ class ETreeOnlyTestCase(HelperTestCase):
         self.assertEquals(["CTEXT"],
                           text)
 
+    def test_elementtree_find_qname(self):
+        XML = self.etree.XML
+        ElementTree = self.etree.ElementTree
+        QName = self.etree.QName
+        tree = ElementTree(XML('<a><b><c/></b><b/><c><b/></c></a>'))
+        self.assertEquals(tree.find(QName("c")), tree.getroot()[2])
+
+    def test_elementtree_findall_qname(self):
+        XML = self.etree.XML
+        ElementTree = self.etree.ElementTree
+        QName = self.etree.QName
+        tree = ElementTree(XML('<a><b><c/></b><b/><c><b/></c></a>'))
+        self.assertEquals(len(list(tree.findall(QName("c")))), 1)
+
+    def test_elementtree_findall_ns_qname(self):
+        XML = self.etree.XML
+        ElementTree = self.etree.ElementTree
+        QName = self.etree.QName
+        tree = ElementTree(XML(
+                '<a xmlns:x="X" xmlns:y="Y"><x:b><c/></x:b><b/><c><x:b/><b/></c><b/></a>'))
+        self.assertEquals(len(list(tree.findall(QName("b")))), 2)
+        self.assertEquals(len(list(tree.findall(QName("X", "b")))), 1)
+
     def test_findall_ns(self):
         XML = self.etree.XML
         root = XML('<a xmlns:x="X" xmlns:y="Y"><x:b><c/></x:b><b/><c><x:b/><b/></c><b/></a>')
@@ -1769,6 +1792,19 @@ class ETreeOnlyTestCase(HelperTestCase):
         docinfo = root.getroottree().docinfo
         self.assertEquals(docinfo.URL, "http://no/such/url")
 
+    def test_parse_stringio_base_url(self):
+        etree = self.etree
+        tree = etree.parse(StringIO("<root/>"), base_url="http://no/such/url")
+        docinfo = tree.docinfo
+        self.assertEquals(docinfo.URL, "http://no/such/url")
+
+    def test_parse_base_url_docinfo(self):
+        etree = self.etree
+        tree = etree.parse(fileInTestDir('include/test_xinclude.xml'),
+                           base_url="http://no/such/url")
+        docinfo = tree.docinfo
+        self.assertEquals(docinfo.URL, "http://no/such/url")
+
     def test_HTML_base_url_docinfo(self):
         etree = self.etree
         root = etree.HTML("<html/>", base_url="http://no/such/url")
